package org.expeditee.settings.identity.secrets;

import java.util.Arrays;
import java.util.List;
import java.util.function.Predicate;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import org.expeditee.gui.Frame;
import org.expeditee.items.Text;
import org.expeditee.setting.ArraySetting;
import org.expeditee.setting.TextSetting;

public class KeyList {
	
	public static final TextSetting PersonalKey = new TextSetting("The AES key used to secure your profile frame - do not share with anyone!", "PersonalKey") {	
		@Override
		public Text generateText() {
			Text t = new Text("PersonalKey");
    		return t;
		}
	};
	
	public static final TextSetting PrivateKey = new TextSetting("The RSA key used to decrypt things encrypted with your RSA public key - do not share with anyone!", "PrivateKey") {	
		@Override
		public Text generateText() {
			Text t = new Text("PrivateKey");
    		return t;
		}
	};
	
	public static final ArraySetting<Text> UserLabels = new ArraySetting<Text>("The labels (and their associated keys) that you have either created or recieved.", 
			"UserLabels", new Text[] { }) {
		
		@Override
		public boolean setSetting(Text text) {
			Frame child = text.getChild();
    		if (child == null) {
    			return false;
    		}
    		
    		Predicate<Text> hasNoData = t -> { 
    			List<String> data = t.getData();
    			return data == null || data.isEmpty();
    		};
    		List<Text> textItems = child.getBodyTextItems(false);
    		textItems.removeIf(hasNoData);
    		_value = textItems.toArray(new Text[] {});
    		
    		return true;
		}
		
		@Override
		public Text generateRepresentation(String label, String frameset) {
			Text t = new Text(label);
			
			createChildFrame(frameset, t, "My Labels");
			
			return t;
		}
	};
	
	public static List<String> getLabelsNameOnly() {
		Text[] allLabels = UserLabels.get();
		Stream<String> allLabelsNames = Arrays.asList(allLabels).stream().map(label -> label.getText());
		return allLabelsNames.collect(Collectors.toList());
	}

	public static Text getByName(String labelName) {
		Text[] allLabels = UserLabels.get();
		for (Text label: allLabels) {
			if (label.getText().equals(labelName)) {
				return label;
			}
		}
		
		return null;
	}
}
